==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QPointingDeviceUniqueId_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qevent.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPointingDeviceUniqueId(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPointingDeviceUniqueId")
    QPointingDeviceUniqueId *_ptr = reinterpret_cast<QPointingDeviceUniqueId *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPointingDeviceUniqueId()
void __qt_construct_QPointingDeviceUniqueId_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPointingDeviceUniqueId()")
    Q_UNUSED(__java_arguments)
    QPointingDeviceUniqueId *__qt_this = new(__qtjambi_ptr) QPointingDeviceUniqueId();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPointingDeviceUniqueId
void __qt_destruct_QPointingDeviceUniqueId(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPointingDeviceUniqueId")
    reinterpret_cast<QPointingDeviceUniqueId*>(ptr)->~QPointingDeviceUniqueId();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPointingDeviceUniqueId::QPointingDeviceUniqueId()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_initialize_1native__Lio_qt_gui_QPointingDeviceUniqueId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPointingDeviceUniqueId::QPointingDeviceUniqueId()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPointingDeviceUniqueId_0, sizeof(QPointingDeviceUniqueId), typeid(QPointingDeviceUniqueId), false, &deleter_QPointingDeviceUniqueId, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPointingDeviceUniqueId::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPointingDeviceUniqueId::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPointingDeviceUniqueId::numericId()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_numericId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPointingDeviceUniqueId::numericId()const", __qt_this)
        qint64 __qt_return_value = __qt_this->numericId();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPointingDeviceUniqueId::operator==(QPointingDeviceUniqueId,QPointingDeviceUniqueId)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_operator_1equal_1native_1QPointingDeviceUniqueId__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPointingDeviceUniqueId::operator==(QPointingDeviceUniqueId,QPointingDeviceUniqueId)", __qt_this)
        QPointingDeviceUniqueId __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QPointingDeviceUniqueId>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPointingDeviceUniqueId::fromNumericId(qint64)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_fromNumericId__J)
(JNIEnv *__jni_env,
 jclass,
 jlong id0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPointingDeviceUniqueId::fromNumericId(qint64)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QPointingDeviceUniqueId __qt_return_value = QPointingDeviceUniqueId::fromNumericId(static_cast<qint64>(id0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPointingDeviceUniqueId(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPointingDeviceUniqueId>("QPointingDeviceUniqueId", "io/qt/gui/QPointingDeviceUniqueId");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPointingDeviceUniqueId, {
        ConstructorInfo(&__qt_construct_QPointingDeviceUniqueId_0, nullptr)
    });
// END: function table

    registerMetaObject(typeId, QPointingDeviceUniqueId::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPointingDeviceUniqueId);
    registerMetaType<QPointingDeviceUniqueId>("QPointingDeviceUniqueId");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QPointingDeviceUniqueId_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qevent.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPointingDeviceUniqueId(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPointingDeviceUniqueId")
    QPointingDeviceUniqueId *_ptr = reinterpret_cast<QPointingDeviceUniqueId *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPointingDeviceUniqueId()
void __qt_construct_QPointingDeviceUniqueId_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPointingDeviceUniqueId()")
    Q_UNUSED(__java_arguments)
    QPointingDeviceUniqueId *__qt_this = new(__qtjambi_ptr) QPointingDeviceUniqueId();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPointingDeviceUniqueId
void __qt_destruct_QPointingDeviceUniqueId(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPointingDeviceUniqueId")
    reinterpret_cast<QPointingDeviceUniqueId*>(ptr)->~QPointingDeviceUniqueId();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPointingDeviceUniqueId::QPointingDeviceUniqueId()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_initialize_1native__Lio_qt_gui_QPointingDeviceUniqueId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPointingDeviceUniqueId::QPointingDeviceUniqueId()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPointingDeviceUniqueId_0, sizeof(QPointingDeviceUniqueId), typeid(QPointingDeviceUniqueId), false, &deleter_QPointingDeviceUniqueId, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPointingDeviceUniqueId::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPointingDeviceUniqueId::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPointingDeviceUniqueId::numericId()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_numericId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPointingDeviceUniqueId::numericId()const", __qt_this)
        qint64 __qt_return_value = __qt_this->numericId();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPointingDeviceUniqueId::operator==(QPointingDeviceUniqueId,QPointingDeviceUniqueId)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_equals_1native_1QPointingDeviceUniqueId__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPointingDeviceUniqueId::operator==(QPointingDeviceUniqueId,QPointingDeviceUniqueId)", __qt_this)
        QPointingDeviceUniqueId __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QPointingDeviceUniqueId>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPointingDeviceUniqueId::fromNumericId(qint64)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_fromNumericId__J)
(JNIEnv *__jni_env,
 jclass,
 jlong id0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPointingDeviceUniqueId::fromNumericId(qint64)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QPointingDeviceUniqueId __qt_return_value = QPointingDeviceUniqueId::fromNumericId(static_cast<qint64>(id0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPointingDeviceUniqueId_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPointingDeviceUniqueId *__qt_this = QtJambiAPI::objectFromNativeId<QPointingDeviceUniqueId>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPointingDeviceUniqueId(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPointingDeviceUniqueId>("QPointingDeviceUniqueId", "io/qt/gui/QPointingDeviceUniqueId");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPointingDeviceUniqueId, {
        ConstructorInfo(&__qt_construct_QPointingDeviceUniqueId_0, nullptr)
    });
// END: function table

    registerMetaObject(typeId, QPointingDeviceUniqueId::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPointingDeviceUniqueId);
    registerMetaType<QPointingDeviceUniqueId>("QPointingDeviceUniqueId");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
